@@ -4,7 +4,7 @@
 # Pod stripped from pm file by OODoc 1.05.
 package XML::Compile::Translate::Reader;
 use vars '$VERSION';
-$VERSION = '0.95';
+$VERSION = '0.96';
 
 use base 'XML::Compile::Translate';
 
@@ -401,7 +401,7 @@ sub makeBlockHandler
 
 sub makeElementHandler
 {   my ($self, $path, $label, $min, $max, $required, $optional) = @_;
-    $max eq "0" and return sub {};
+    $max eq "0" and return sub {};  # max can be "unbounded"
 
     if($max ne 'unbounded' && $max==1)
     {   return $min==1
@@ -494,7 +494,6 @@ sub makeElementHref
 
 sub makeElement
 {   my ($self, $path, $ns, $childname, $do) = @_;
-
     sub { my $tree  = shift;
           my $value = defined $tree && $tree->nodeType eq $childname
              ? $do->($tree) : $do->(undef);
